@@ -38,7 +38,7 @@ def check_remote_path(remote_machine, root_path):
 
 
 def generate_exec_filesystem(protocol_triad, cache_dir, job_data, runtime_root_path, batch_job_code, 
-        data_transfer_protocol, env_instr=None, build_envroot=None):
+        data_transfer_protocol, env_instr=None, build_envroot=None, only_gather=False):
     
     devnull = open('/dev/null', 'w')
 
@@ -124,7 +124,7 @@ def generate_exec_filesystem(protocol_triad, cache_dir, job_data, runtime_root_p
                 runtime_shdest_path = shared[skey]
             exec_filesystem[jd['unique_code']][1]["<shared>"+skey] = runtime_shdest_path
 
-    if protocol == 'remote' and not env_and_do_not_replicate:
+    if protocol == 'remote' and (not env_and_do_not_replicate) and (not only_gather):
         check_remote_path(remote_machine, fs_locations["runtime_root"])
 
     # Step 3: create Work sub-filesystem: "custom" or "locusts" mode -------------------
@@ -255,7 +255,7 @@ def create_manager_scripts(protocol_triad, cache_dir, task_folders, partition,
         data_transfer_protocol, singinfo=(None, None, None), task_cd=None,
         email_address="", email_type="ALL", tasks_per_core=1, min_stack_per_core=10,
         constraint='', nodescratch_folder="", nodescratch_mem="", walltime="24:00:00",
-        outer_statements="", exclusive=False, mem='', mempercpu=''):
+        outer_statements="", exclusive=False, mem='', mempercpu='', only_gather=False):
 
     protocol, remote_machine, hpc_shared_folder = protocol_triad
     devnull = open('/dev/null', 'w')
@@ -416,6 +416,9 @@ def create_manager_scripts(protocol_triad, cache_dir, task_folders, partition,
         # Job manager identifier and associated tasks
         tasks_per_job.append((jobid, taskid_list[ik:ik+tasks_per_node]))
 
+    if only_gather:
+        return tasks_per_job, ""
+
     manager_cmd, macname = [], {}
     manager_cmd.append("echo MANAGERS")
     for job_id, task_list in tasks_per_job:
@@ -453,7 +456,7 @@ def create_manager_scripts(protocol_triad, cache_dir, task_folders, partition,
 
 
 def remote_job_control(protocol_triad, batch_job_code, fs_locations, tasks_per_job,
-        waiting_time):
+        waiting_time, only_gather=False):
     # There must be a passwordless connection between the two machines: to
     # achieve it, ssh-agent and then ssh-add.
     # If the two machines share a folder - and thus there is no need to ssh to
@@ -462,34 +465,36 @@ def remote_job_control(protocol_triad, batch_job_code, fs_locations, tasks_per_j
     protocol, remote_machine, hpc_shared_folder = protocol_triad
     devnull = open('/dev/null', 'w')
 
-    if protocol != 'local':
-        for job_id, task_list in tasks_per_job:
-            chk_cmd = [
-                "ssh",
-                remote_machine,
-                "sbatch",
-                fs_locations["runtime_exec"] + 'outer_manager_{0}{1}.slurm' \
-                    .format(batch_job_code, str(job_id).zfill(3))
-            ]
-            if DEBUG:
-                print("COMMAND", " ".join(chk_cmd))
-                p = subprocess.Popen(chk_cmd)
-            else:
-                p = subprocess.Popen(chk_cmd,
-                    stderr=devnull,
-                    stdout=devnull
-                )
-    else:
-        # If no hpc, there is only one node, i.e. one manager
-        mname = 'outer_manager_{0}{1}.slurm'.format(batch_job_code, str(0).zfill(3))
-        nhp_cmd = ["nohup", fs_locations["runtime_exec"] + mname]
-        if DEBUG:
-            print("COMMAND", nhp_cmd)
-            p = subprocess.Popen(nhp_cmd)
+    if not only_gather:
+        if protocol != 'local':
+            for job_id, task_list in tasks_per_job:
+                chk_cmd = [
+                    "ssh",
+                    remote_machine,
+                    "sleep 60;",
+                    "sbatch",
+                    fs_locations["runtime_exec"] + 'outer_manager_{0}{1}.slurm' \
+                        .format(batch_job_code, str(job_id).zfill(3))
+                ]
+                if DEBUG:
+                    print("COMMAND", " ".join(chk_cmd))
+                    p = subprocess.Popen(chk_cmd)
+                else:
+                    p = subprocess.Popen(chk_cmd,
+                        stderr=devnull,
+                        stdout=devnull
+                    )
         else:
-            p = subprocess.Popen(nhp_cmd,
-                stderr=devnull, stdout=devnull
-            )
+            # If no hpc, there is only one node, i.e. one manager
+            mname = 'outer_manager_{0}{1}.slurm'.format(batch_job_code, str(0).zfill(3))
+            nhp_cmd = ["nohup", fs_locations["runtime_exec"] + mname]
+            if DEBUG:
+                print("COMMAND", nhp_cmd)
+                p = subprocess.Popen(nhp_cmd)
+            else:
+                p = subprocess.Popen(nhp_cmd,
+                    stderr=devnull, stdout=devnull
+                )
 
     waitcount = {}
     for job_id, task_list in tasks_per_job:
@@ -503,9 +508,13 @@ def remote_job_control(protocol_triad, batch_job_code, fs_locations, tasks_per_j
     job_times = {job_id : 0 for job_id, task_list in tasks_per_job}
     hasrun = {job_id : False for job_id, task_list in tasks_per_job}
     sc, wc = 0, 0
+    first_time = True
     while not is_over:
         status = {job_id : '' for job_id, task_list in tasks_per_job}
-        time.sleep(waiting_time)
+        if not (only_gather and first_time):
+            time.sleep(waiting_time)
+        else:
+            first_time = False
         is_over = True
 
         # Start/stop chronometer
@@ -595,88 +604,6 @@ def remote_job_control(protocol_triad, batch_job_code, fs_locations, tasks_per_j
                 print(job_id, "End")
                 time_end[job_id] = job_times[job_id]
 
-        continue
-
-        if machine_names[job_id] == "NoHostname":
-            if DEBUG:
-                print("COMMAND", machinename_cmd)
-                mname_txt = subprocess.Popen(
-                    machinename_cmd,
-                    stdout=subprocess.PIPE
-                ).stdout.read().decode('utf-8')
-            else:
-                mname_txt = subprocess.Popen(
-                    machinename_cmd,
-                    stdout=subprocess.PIPE,
-                    stderr=devnull
-                ).stdout.read().decode('utf-8')
-            if mname_txt.strip():
-                machine_names[job_id] = mname_txt.split()[1]
-
-            if touch_time_txt.strip():
-                if DEBUG:
-                    print("COMMAND", chk_time_cmd)
-                    local_time_l = subprocess.Popen(
-                        chk_time_cmd,
-                        stdout=subprocess.PIPE,
-                        shell=True
-                    ).stdout.read().decode('ascii').split()[0].split(":")
-                else:
-                    local_time_l = subprocess.Popen(
-                        chk_time_cmd, 
-                        stderr=devnull, 
-                        stdout=subprocess.PIPE, 
-                        shell=True
-                    ).stdout.read().decode('ascii').split()[0].split(":")
-                touch_time = int(touch_time_txt.split(":")[0])*60 + int(touch_time_txt.split(":")[1])
-                local_time = int(local_time_l[0])*60 + int(local_time_l[1])
-                coeff = (local_time - touch_time)%(24*60)
-                is_active = False if coeff > 1 else True
-                if is_active:
-                    is_over = False
-                    chrono_on[job_id] = True
-                    print("Job", job_id, "running", machine_names[job_id])
-                else:
-                    chrono_on[job_id] = False
-                    print("Job", job_id, "ended")
-            else:
-                is_there = False
-                # Check if processes are scehduled. For this you need the job IDs given by the machine...
-                if protocol != 'local':
-                    isitthere_cmd = ["ssh " + remote_machine + ' \'squeue --format="%.18i %.9P %.100j %.8u %.2t %.10M %.6D %R"\'']
-                    if DEBUG:
-                        print("COMMAND", isitthere_cmd)
-                        isitthere_txt = subprocess.Popen(
-                            isitthere_cmd,
-                            stdout=subprocess.PIPE,
-                            shell=True
-                        ).stdout.read().decode('ascii')
-                    else:
-                        isitthere_txt = subprocess.Popen(
-                            isitthere_cmd, 
-                            stderr=devnull, 
-                            stdout=subprocess.PIPE, 
-                            shell=True
-                        ).stdout.read().decode('ascii')
-                    for line in isitthere_txt.split("\n")[1:]:
-                        if not line.strip():
-                            continue
-                        fields = line.split()
-                        if fields[2].strip() == '{0}{1}'.format(batch_job_code, str(job_id).zfill(3)):
-                            print("Job", job_id, "pending")
-                            is_there = True
-                            is_over = False
-                            break
-                    if not is_there:
-                        waitcount[job_id] += 1
-                        if waitcount[job_id] > 3:
-                            print("Job", job_id, "error/aborted")
-                        else:
-                            print("Job", job_id, "waiting...")
-                            is_over = False
-                else:
-                    print("Job", job_id, "error/aborted")
-
     log_txt = "\n\n#LOCUSTS JOBS LOG\n"
     time_now = time.time()
     tot_runtime, totsq = 0, 0
@@ -1067,6 +994,12 @@ def highly_parallel_job_manager(options, exec_filename,
     waiting_time = options['waiting_time']
     memory = options['memory']
     memory_per_cpu = options['memory_per_cpu']
+    only_gather = options['only_gather']
+
+    print("ONLY GATHER", only_gather)
+    if not only_gather:
+        print("STOP")
+        exit(1)
 
     log_txt = ("#RUN LOG\n\n"
         "Run type (local / shared / remote) :\t{0}\n").format(protocol)
@@ -1097,7 +1030,8 @@ def highly_parallel_job_manager(options, exec_filename,
             batch_job_code,
             data_transfer_protocol,
             env_instr=env_instr,
-            build_envroot=gen_env_root_dir
+            build_envroot=gen_env_root_dir,
+            only_gather=only_gather
         )
 
         # Create local manager script that does the mpiq job, launchable on each node. It checks the situation regularly each 10 secs.
@@ -1121,7 +1055,8 @@ def highly_parallel_job_manager(options, exec_filename,
             outer_statements=out_st,
             exclusive=exclusive,
             mem=memory,
-            mempercpu=memory_per_cpu
+            mempercpu=memory_per_cpu,
+            only_gather=only_gather
         )
         log_txt += tmp_log_txt
 
@@ -1146,14 +1081,18 @@ def highly_parallel_job_manager(options, exec_filename,
         lenlist = [len(x[1]) for x in tasks_per_job]
         if waiting_time == -1:
             waiting_time = min(600, 10*(1+len(job_data)//min(lenlist)))
+        if not only_gather:
+            time.sleep(max(60,waiting_time))
         log_txt += remote_job_control(
             protocol_triad,
             batch_job_code, 
             fs_locations, 
             tasks_per_job, 
-            waiting_time
+            waiting_time,
+            only_gather=only_gather
         )
 
+
         # Collect results, update job_data (only processes that remained pending on running are written in job_data again
         job_data, outp, witherr = gather_results(
             protocol_triad,
